# (C) Copyright HCL Technologies Limited 2018
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2, or (at your option)
#  any later version.
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
# 
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
# 
#  Author: IBM Corporation and/or HCL Technologies Ltd.
#  This module is part of the IBM (R) Rational (R) ClearCase (R)(*)
#  Multi-version file system (MVFS).
#  For support, please visit http://www.ibm.com/software/support
# 
#  * ClearCase is a trademark of IBM Corporation, registered in many
#    jurisdictions, and is used under license.
%define cc_min_ver 9.0.1.0
%define cc_not_allowed  ""
%define cc_path "/opt/rational/clearcase"
%define cc_cleartool "%{cc_path}/bin/cleartool"
%define cc_vrmf_calc() %(expr %(echo %1 | cut -d . -f 1) \\* 1000000 + %(echo %1 | cut -d . -f 2) \\* 10000 + %(echo %1 | cut -d . -f 3) \\* 100 + `echo %1 | cut -d . -f 4`)
%define cc_vrmf_comp(a:b:) %(if test %{cc_vrmf_calc %{-a*}} -eq %{cc_vrmf_calc %{-b*}} ; then echo 0 ; else test %{cc_vrmf_calc %{-a*}} -gt %{cc_vrmf_calc %{-b*}} && echo "1" || echo "-1" ; fi)
%define mygetenv(v:) %(echo -n "$%{-v*}")
%define myisset(v:) %(typeset -p "%{-v*}" &> /dev/null && echo -n 1 || echo -n 0)
%define cc_installed_version %(%{cc_cleartool} -ver | sed -ne 's@ClearCase version \\([0-9.]\\+\\).*@\\1@p' | tail -n1)

%define name mvfs

# dist, if not defined, use default
%if "0%{?mvfsnodist}" == "0"
%if "0%{?mvfsdist}" == "0"
%if "%{myisset -v MVFSDIST}" == "0"
%define MVFSDIST %{?dist}
%else
%define MVFSDIST %{mygetenv -v MVFSDIST}
%endif
%else
%define MVFSDIST %{?mvfsdist}
%endif
%else
%undefine MVFSDIST
%endif
# extra tag, if not defined "priv".
%if "0%{?mvfsnoxtag}" == "0"
%if "%{myisset -v MVFSXTAG}" == "0"
%define MVFSXTAG priv
%else
%define MVFSXTAG %{mygetenv -v MVFSXTAG}
%endif
%endif
%if "0%{?mvfsnokversion}" == "0"
%if "0%{?mvfskversion}" == "0"
%if "%{myisset -v MVFSKVERSION}" == "0"
%define MVFSKVERSION %(uname -r)
%else
%define MVFSKVERSION %{mygetenv -v MVFSKVERSION}
%endif
%else
%define MVFSKVERSION %{mvfskversion}
%endif
%endif
%if "0%{?MVFSKVERSION}" == "0"
%undefine bkversion 
%else
# bkversion is the base kernel version (no suffix, no arch)
%define bkversion %(echo %{MVFSKVERSION}_ | sed -e '/%{_arch}/ s@[._-]\\?%{_arch}@@' -e 's@[._-]\\?el[0-9]\\+@@' | tr '-' '_')
%endif
# extract version from source code
%define version %(sed -ne 's@.*define[[:space:]]\\+TBS_RATIONAL_RELEASE_\\(GROUP\\|M[AI][JN]OR\\|BUILD\\)[[:space:]]\\+"\\?\\([0-9]\\+\\)"\\?.*@\\2@p' tbs_major_ver_str.h | paste -s -d .)
# extract date from mvfs_when.h
%define mvfs_date %(date -u -d "`sed -ne 's@^[[:space:]]*#[[:space:]]*define[[:space:]]\\+MVFS_WHEN_STRING[[:space:]]\\+"\\(.*\\)"@\\1@p' mvfs_when.h`" +%Y%m%d)%{?MVFSXTAG}
%define release %{?bkversion}%{mvfs_date}%{?MVFSDIST}
%define original_dir %(pwd)

# allow to avoid depmod if not a real install
%if "0%{?mvfsnodepmod}" == "0"
%if "%{myisset -v MVFSDEPMOD}" == "1"
%define MVFSDEPMOD %{mygetenv -v MVFSDEPMOD}
%endif
%else
%define MVFSDEPMOD DEPMOD=
%endif

%define mvfs_src_dir %{name}-%{version}_%{mvfs_date}

Name:           %{name}
Version:        %{version}
Release:        %{release}
Summary:        MVFS is the Linux kernel driver for ClearCase dynamic views.
License:        GPL
URL:            http://www.ibm.com/software/support
Source0:        %{mvfs_src_dir}.tgz
BuildRequires:  gcc kernel-headers
Group:		Unspecified
Requires:	bash

%{echo:buildroot=%buildroot}

%description
MVFS Linux kernel driver for ClearCase dynamic views.

%prep
rm -f %{_sourcedir}/%{mvfs_src_dir}
ln -s %{original_dir} %{_sourcedir}/%{mvfs_src_dir}
cd %{_builddir} && rm -fr %{mvfs_src_dir}
ln -s %{_sourcedir}/%{mvfs_src_dir} %{_builddir}/%{mvfs_src_dir}
%define MVFSNOTGZ %{mygetenv -v MVFSNOTGZ}
%if "0%{?MVFSNOTGZ}" == "0"
rm -f %{_sourcedir}/%{mvfs_src_dir}.tgz 
tar zcvf %{_sourcedir}/%{mvfs_src_dir}.tgz %{mvfs_src_dir}/
%endif
#%setup -q

%build
cd %{mvfs_src_dir}
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
cd %{mvfs_src_dir}
make INSTALL_DIR=%{buildroot}/lib/modules/%{MVFSKVERSION}/kernel/fs/mvfs %{?MVFSDEPMOD}  install

%pre
# check minimum version
%if "%{cc_vrmf_comp -a %{cc_min_ver} -b %{cc_installed_version}}" == "1"
%{error:%name %version requires ClearCase %{cc_min_ver} at minimum}
exit 1
%else
# check not-allowed list
%if %(for i in %{cc_not_allowed} ; do if [ "$i" = %{cc_installed_version} ] ; then echo "no" ; exit; fi; done; echo "yes") == "no"
%{error:%name %version not allowed on this ClearCase version}
%endif
%endif

%post
depmod

%postun
depmod

%files
/lib/modules/%{MVFSKVERSION}/kernel/fs/mvfs/mvfs.ko
%dir /lib/modules/%{MVFSKVERSION}/kernel/fs/mvfs

%debug_package

%changelog
# $Id: 55f7cf61.d0f611e8.888d.00:50:56:9b:7a:9e $ 
